pub struct MenuItemIdentifierDynamic<U>where
U: MenuItemIdentifierDynamicUpdate,{ /* private fields */ }Trait Implementations
Sourceimpl<U> Component for MenuItemIdentifierDynamic<U>where
U: MenuItemIdentifierDynamicUpdate,
impl<U> Component for MenuItemIdentifierDynamic<U>where
U: MenuItemIdentifierDynamicUpdate,
Sourcetype Output = ()
type Output = ()
The type yielded by the component in response to an event. Typical components only yield
meaningful results when certain conditions have been met (e.g. an item is chosen from a
menu), thus it’s common for this type to be
Option<_>.Sourcetype State = ()
type State = ()
The type of the external state of this component. This allows multiple different components
to share the same piece of state. For components whose entire state is contained within the
component itself, set this to
().Sourcefn render(
&self,
state: &<MenuItemIdentifierDynamic<U> as Component>::State,
ctx: Ctx<'_>,
fb: &mut FrameBuffer,
)
fn render( &self, state: &<MenuItemIdentifierDynamic<U> as Component>::State, ctx: Ctx<'_>, fb: &mut FrameBuffer, )
Render the component to a frame buffer
Sourcefn update(
&mut self,
_state: &mut <MenuItemIdentifierDynamic<U> as Component>::State,
_ctx: Ctx<'_>,
event: Event,
) -> <MenuItemIdentifierDynamic<U> as Component>::Output
fn update( &mut self, _state: &mut <MenuItemIdentifierDynamic<U> as Component>::State, _ctx: Ctx<'_>, event: Event, ) -> <MenuItemIdentifierDynamic<U> as Component>::Output
Update the internal and extnal state of this component in response to an event, and yield a
value.
Sourcefn size(
&self,
state: &<MenuItemIdentifierDynamic<U> as Component>::State,
ctx: Ctx<'_>,
) -> UCoord
fn size( &self, state: &<MenuItemIdentifierDynamic<U> as Component>::State, ctx: Ctx<'_>, ) -> UCoord
Return the current size (in cells) of this component. This allows decorators to account for
the size of the components they decorate (e.g. when drawing a border around a component, its
size must be known).
Sourceimpl<U> MenuItemIdentifier for MenuItemIdentifierDynamic<U>where
U: MenuItemIdentifierDynamicUpdate,
impl<U> MenuItemIdentifier for MenuItemIdentifierDynamic<U>where
U: MenuItemIdentifierDynamicUpdate,
fn init_selection(&mut self, selection: bool)
fn set_selection(&mut self, selection: bool)